/* Cattle - Brainfuck language toolkit
 * Copyright (C) 2008-2014  Andrea Bolognani <eof@kiyuko.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Homepage: http://kiyuko.org/software/cattle
 */

#ifndef __CATTLE_H__
#define __CATTLE_H__

#define __CATTLE_H_INSIDE__

#include <cattle/cattle-version.h>
#include <cattle/cattle-constants.h>
#include <cattle/cattle-error.h>
#include <cattle/cattle-buffer.h>
#include <cattle/cattle-tape.h>
#include <cattle/cattle-instruction.h>
#include <cattle/cattle-program.h>
#include <cattle/cattle-configuration.h>
#include <cattle/cattle-interpreter.h>

#undef __CATTLE_H_INSIDE__

#endif /* __CATTLE_H__ */
